@@ -15,7 +15,7 @@ has missing_after => 86400;
 has remove_after  => 864000;
 has tasks         => sub { {} };
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -239,7 +239,8 @@ Register a new task.
   my $id = $minion->enqueue(foo => [@args] => {priority => 1});
 
 Enqueue a new job with C<inactive> state. Arguments get serialized, so you
-shouldn't send objects.
+shouldn't send objects, nested data structures with hash and array references
+are fine though.
 
 These options are currently available:
 
