@@ -2,6 +2,7 @@ package Minion::Job;
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Mojo::IOLoop;
+use POSIX 'WNOHANG';
 
 has args => sub { [] };
 has [qw(id minion task)];
@@ -23,17 +24,24 @@ sub finish {
 
 sub info { $_[0]->minion->backend->job_info($_[0]->id) }
 
+sub is_finished {
+  my ($self, $pid) = @_;
+  return undef unless waitpid($pid, WNOHANG) == $pid;
+  $? ? $self->fail("Non-zero exit status (@{[$? >> 8]})") : $self->finish;
+  return 1;
+}
+
 sub perform {
   my $self = shift;
-  waitpid $self->_child, 0;
-  $? ? $self->fail('Non-zero exit status') : $self->finish;
+  waitpid $self->start, 0;
+  $? ? $self->fail("Non-zero exit status (@{[$? >> 8]})") : $self->finish;
 }
 
 sub remove { $_[0]->minion->backend->remove_job($_[0]->id) }
 
 sub retry { $_[0]->minion->backend->retry_job($_[0]->id) }
 
-sub _child {
+sub start {
   my $self = shift;
 
   # Parent
@@ -45,7 +53,8 @@ sub _child {
 
   # Child
   my $task = $self->task;
-  $self->app->log->debug(qq{Performing job "$task" (@{[$self->id]}:$$)});
+  $self->app->log->debug(
+    qq{Performing job "@{[$self->id]}" with task "$task" in process $$});
   my $cb = $self->minion->tasks->{$task};
   $self->fail($@) unless eval { $self->$cb(@{$self->args}); 1 };
   exit 0;
@@ -195,6 +204,12 @@ Get job information.
   # Get job result
   my $result = $job->info->{result};
 
+=head2 is_finished
+
+  my $bool = $job->is_finished($pid);
+
+Check if job performed with L</"start"> is finished.
+
 =head2 perform
 
   $job->perform;
@@ -213,6 +228,20 @@ Remove C<failed>, C<finished> or C<inactive> job from queue.
 
 Transition from C<failed> or C<finished> state back to C<inactive>.
 
+=head2 start
+
+  my $pid = $job->start;
+
+Perform job in new process, but do not wait for it to finish.
+
+  # Perform two jobs concurrently
+  my $pid1 = $job1->start;
+  my $pid2 = $job2->start;
+  my ($first, $second);
+  sleep 1
+    until $first  ||= $job1->is_finished($pid1)
+    and   $second ||= $job2->is_finished($pid2);
+
 =head1 SEE ALSO
 
 L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
